local agent_helper = require(AGENT_PATH .. "agent_helper")

AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	is_login_verify_ing = false,
	login_verify_url = "cls.xxqt.huolug.com/akk/login_verify.php",
	pay_notify_callback_url = "",

	uid = "",
}

function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result) 
		if "true" == result then
			AdapterToLua:endGame()
		end
	end)
end

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	self.is_init = true
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	AgentMs:InitLocalPush()
	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "akk"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "akk_" .. self.uid
end

-- 是否有管理中心
function AgentAdapter:IsHasManagerCenter()
	return true
end

function AgentAdapter:OpenManagerCenter()
	if self:IsHasManagerCenter() and agent_helper.OpenManagerCenter then
		agent_helper:OpenManagerCenter()
	end
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:LoginCallback(result)
	Log("LoginCallback:result=" .. result)
	local json_obj = cjson.decode(result)
	if nil == json_obj or nil == json_obj.uid or nil == json_obj.token_key or nil == json_obj.token_secret then return end

	local verify_callback = function(url, arg, data, size)
		self.is_login_verify_ing = false
		if size <= 0 then
			Log("verify_callback, fail:size<=0")
			return
		end

		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			Log("verify_callback, fail")
			return
		end

		Log("login-verify, success")
		self.uid = ret_t.user.uid
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())
	end

	self.is_login_verify_ing = true
	
	local session_id = json_obj.token_key
	local now_server_time = math.floor(GLOBAL_CONFIG.server_info.server_time + (Status.NowTime - GLOBAL_CONFIG.client_time))
	local sign = UtilEx:md5Data(self:GetSpid() .. session_id .. now_server_time .. LOGIN_VERIFY_KEY)
	local real_url = string.format("%s?spid=%s&token=%s&token_secret=%s&uid=%s&time=%s&sign=%s", self.login_verify_url, self:GetSpid(), json_obj.token_key, json_obj.token_secret, json_obj.uid, now_server_time, sign)
	Log("start verify login: url=" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)

end
function AgentAdapter:LogoutCallback(result)
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
end

function AgentAdapter:Logout()
	self.force_logout = true
	agent_helper:Logout()
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	local data = {}

	data.amount = amount * 100
	data.order = server_id .. "_" .. self.uid .. "_" .. os.time()
	data.desc = "游戏支付"
	data.goods_name = "元宝"
	data.call_back_url = "http://cls.xxqt.huolug.com/akk/pay.php"
	agent_helper:Pay(cjson.encode(data), callback)
end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self:SubmitInfo(0)
end

-- 进入游戏上报
function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(1)
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(2)
end


function AgentAdapter:SubmitInfo(typexx)

	if typexx == 1 then

		local role_vo = GameVoManager.Instance:GetMainRoleVo()
		local user_vo = GameVoManager.Instance:GetUserVo()

		if role_vo ~= nil and user_vo ~= nil then
			local info = {}
			info.server_id = tostring(user_vo.plat_server_id)
			info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
			info.role_name = role_vo.name
			info.role_id = tostring(role_vo.role_id)
			info.user_level = tostring(role_vo.level) or "0"
			info.vip_level = tostring(role_vo.vip_level) or "0"

			if RoleData.Instance and RoleData.Instance.role_info then
				info.gold = RoleData.Instance.role_info.gold or "0"
				info.party_name = RoleData.Instance.role_vo.guild_name or ""
			else
				info.gold = "0"
				info.party_name = ""
			end
			info.sub_type = typexx

			print(cjson.encode(info))
			PlatformBinder:JsonCall("send_user_info", cjson.encode(info));
		end
	end

end