local agent_helper = require(AGENT_PATH .. "agent_helper")

AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	is_login_verify_ing = false,
	login_verify_url = "cls.cp01.youyannet.com/aqy/login_kohalik.php",
	pay_type_url = "cls.cp01.youyannet.com/aqy/pay_type.php",
	uid = "",
}

function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result)
		if "true" == result then
			AdapterToLua:endGame()	
		else
			local format = { title = "退出", message = "退出游戏?", positive = "确定", negative = "取消", }
			PlatformAdapter:OpenAlertDialog(format, 
				function (result) 
					if "positive" == result then 
						AdapterToLua:endGame()
						end 
				end)
		end
	end)
end


-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	
	local cache_data = Split((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), "_")
	if cache_data ~= nil then
		GLOBAL_CONFIG.package_info.config.agent_id = cache_data[1] or "aqy"
		self.uid = cache_data[2] or ""
	end

	print("===========", self.uid)

	self.is_init = true
	AgentMs:InitLocalPush()

	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)

	local channel_id = PlatformBinder:JsonCall("call_get_channelId") or ""
	self:SetChanneId(channel_id)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return GLOBAL_CONFIG.package_info.config.agent_id
end

function AgentAdapter:GetChannelId()
	return "aqy"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return self:GetSpid() .. "_" .. self.uid
end

--获得loadingbgname
function AgentAdapter:GetLoadingbgName()
	return "loading_bg_aqy"
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[13]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "big_logo_yjms"
end

function AgentAdapter:LoginCallback(result)
	local json_obj = cjson.decode(result)
	self.uid = json_obj.userId

		local verify_callback = function(url, arg, data, size)
		self.is_login_verify_ing = false
		if size <= 0 then
			Log("verify_callback, fail:size<=0")
			return
		end
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			Log("verify_callback, fail")
			return
		end
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())
	end

	self.is_login_verify_ing = true
	AdapterToLua:getInstance():setDataCache("PRVE_ACCOUNT_LW_CODE", self.uid)
	local now_server_time = math.floor(GLOBAL_CONFIG.server_info.server_time + (Status.NowTime - GLOBAL_CONFIG.client_time))

	local real_url = string.format("%s?spid=%s&uid=%s", self.login_verify_url, self:GetSpid(), self.uid)

	Log("start verify login: url=" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:SwitchAccount(callback)
	self.login_callback = callback
	agent_helper:Logout()
end

function AgentAdapter:LogoutCallback(result)
	if "true" == result then
		self.uid = ""
		if not LoginController.Instance:AgentLoginViewIsOpen() then
			ReStart()
		end
	end
	return true
end

function AgentAdapter:Logout()
	self.force_logout = true
	agent_helper:Logout()
end

function AgentAdapter:UIEventCallback(event)
	if "open" == event then
		--self:ShowFloatButton()
	elseif "close" == event then
		--self:ShowFloatButton()
	end
	return true
end

-- function AgentAdapter:ShowFloatButton()
-- 	agent_helper:ShowFloatButton(70, 30, true)
-- end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	local verify_callback = function(url, arg, data, size)	
		local ret_t = cjson.decode(data)
		if ret_t ~= nil then
			local info = {}
			local role_vo = GameVoManager.Instance:GetMainRoleVo()
			info.pay_type = tostring(ret_t.pay_type) 
			info.server_id = server_id
			info.uid = self.uid
			info.game_name = self:GetGameName()
			info.amount = amount
			info.role_id = tostring(role_vo.role_id)
			info.roleName = role_vo.name
			info.level = tostring(role_vo.level)
			info.Product_Count = "1"
			info.Role_Balance = "0" 
			info.Product_Name = "元宝"
			info.ext = server_id .. "_" .. self:GetPlatName() .. "_" .. os.time()
			agent_helper:Pay(cjson.encode(info), callback)
		end
		
	end

	HttpClient:Request(self.pay_type_url, "", verify_callback)

	
end

-- 进入游戏上报
function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	self:ReportRoleInfo("1")
end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self:ReportRoleInfo("2")
end

function AgentAdapter:ReportRoleInfo(dataType)
	local main_role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()

	if main_role_vo == nil or user_vo == nil then return end

	local info = {}

	info.dataType = dataType
	info.roleName = main_role_vo.role_name
	info.role_id = tostring(main_role_vo.role_id)
	info.serverId =tostring(user_vo.plat_server_id) 
	info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
	info.level = tostring(main_role_vo.level)
	info.ext = ""

	agent_helper:SubmitExtendData(cjson.encode(info))
end


function AgentAdapter:EnterUserCenter()
	agent_helper:EnterUserCenter()
end

-- 是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end

channelIds = {}
channelIds["000001"] = "t00"	--谷歌 
channelIds["000002"] = "t01"	--机锋 
channelIds["000003"] = "t02"	--当乐 
channelIds["000004"] = "t03"	--N多 
channelIds["000005"] = "t04"	--安智市场 
channelIds["000006"] = "t05"	--安卓网 
channelIds["000007"] = "t06"	--百度91 
channelIds["000008"] = "t07"	--木蚂蚁 
channelIds["000009"] = "t08"	--应用汇 
channelIds["000012"] = "t09"	--三星应用商店 
channelIds["000013"] = "t0a"	--移动mm 
channelIds["000014"] = "t0b"	--魅族应用商店 
channelIds["000016"] = "t0c"	--联想应用商店 
channelIds["000017"] = "t0d"	--优亿市场 
channelIds["000019"] = "t0e"	--索爱应用商店 
channelIds["000020"] = "t0f"	--可可游戏中心(OPPO) 
channelIds["000023"] = "t10"	--360手机助手 
channelIds["000030"] = "t11"	--极游 
channelIds["000032"] = "t12"	--电信 
channelIds["000041"] = "t13"	--朵唯应用商店 
channelIds["000053"] = "t14"	--点心 
channelIds["000054"] = "t15"	--华为应用商店 
channelIds["000056"] = "t16"	--联通 
channelIds["000057"] = "t17"	--中兴应用商店 
channelIds["000066"] = "t18"	--小米应用商店 
channelIds["000072"] = "t19"	--3G门户 
channelIds["000078"] = "t1a"	--酷派应用商店 
channelIds["000084"] = "t1b"	--金立应用商店 
channelIds["000085"] = "t1c"	--飞流应用商店 
channelIds["000091"] = "t1d"	--搜狐 
channelIds["000097"] = "t1e"	--网易应用商店 
channelIds["000108"] = "t1f"	--4399手机开放平台 
channelIds["000116"] = "t20"	--豌豆荚 
channelIds["000119"] = "t21"	--天语市场 
channelIds["000123"] = "t22"	--PPTV 
channelIds["000215"] = "t23"	--百度多酷 
channelIds["000221"] = "t24"	--汇智广告
channelIds["000222"] = "t25"	--巴士商店 
channelIds["000243"] = "t26"	--七匣子 
channelIds["000247"] = "t27"	--拇指玩 
channelIds["000266"] = "t28"	--移动游戏基地 
channelIds["000286"] = "t29"	--金立游戏中心（单机） 
channelIds["000310"] = "t2a"	--悠悠村应用商店 
channelIds["000312"] = "t2b"	--极游盛大 
channelIds["000316"] = "t2c"	--斯凯应用商店 
channelIds["000318"] = "t2d"	--手游天下 
channelIds["000322"] = "t2e"	--阿里云平台 
channelIds["000323"] = "t2f"	--泡椒 
channelIds["000324"] = "t30"	--乐蛙 
channelIds["000328"] = "t31"	--三星游戏中心 
channelIds["000329"] = "t32"	--千尺终端卖场 
channelIds["000330"] = "t33"	--爱游游戏应用商店 
channelIds["000341"] = "t34"	--天奕达应用商店 
channelIds["000349"] = "t35"	--欧朋浏览器 
channelIds["000368"] = "t36"	--步步高应用商店(vivo) 
channelIds["000369"] = "t37"	--游戏狗应用商店 
channelIds["000371"] = "t38"	--宝软 
channelIds["000372"] = "t39"	--软吧 
channelIds["000373"] = "t3a"	--聚好玩 
channelIds["000376"] = "t3b"	--有米 
channelIds["000380"] = "t3c"	--闻泰应用商店 
channelIds["000386"] = "t3d"	--TCL应用商店 
channelIds["000398"] = "t3e"	--酷安 
channelIds["000406"] = "t3f"	--多米音乐 
channelIds["000415"] = "t40"	--Amazon 
channelIds["000420"] = "t41"	--波导应用商店 
channelIds["000424"] = "t42"	--苏宁应用商店 
channelIds["000425"] = "t43"	--苏宁卖场 
channelIds["000428"] = "t44"	--游戏宝 
channelIds["000432"] = "t45"	--上海然诺 
channelIds["000433"] = "t46"	--杭州掌盟 
channelIds["000438"] = "t47"	--暴风影音 
channelIds["000439"] = "t48"	--天天动听 
channelIds["000440"] = "t49"	--酷狗音乐 
channelIds["000441"] = "t4a"	--金山电池 
channelIds["000442"] = "t4b"	--pps 
channelIds["000447"] = "t4c"	--绿豆刷机 
channelIds["000453"] = "t4d"	--万普 
channelIds["000454"] = "t4e"	--鼎开 
channelIds["000466"] = "t4f"	--优酷 
channelIds["000481"] = "t50"	--梦宝谷 
channelIds["000487"] = "t51"	--和讯PUSH 
channelIds["000491"] = "t52"	--新浪微游戏 
channelIds["000495"] = "t53"	--指点 
channelIds["000514"] = "t54"	--鼎为 
channelIds["000515"] = "t55"	--17SY应用商店 
channelIds["000520"] = "t56"	--琵琶网 
channelIds["000524"] = "t57"	--900市场 
channelIds["000527"] = "t58"	--历趣 
channelIds["000550"] = "t59"	--腾讯应用宝 
channelIds["000551"] = "t5a"	--聚乐 
channelIds["000556"] = "t5b"	--酷我音乐 
channelIds["000631"] = "t5c"	--E人E本应用商店 
channelIds["000648"] = "t5d"	--飞讯 
channelIds["000650"] = "t5e"	--掌信 
channelIds["000683"] = "t5f"	--7k7k游戏 
channelIds["000684"] = "t60"	--趣源 
channelIds["000686"] = "t61"	--快手看片 
channelIds["000709"] = "t62"	--我要玩游戏 
channelIds["000724"] = "t63"	--支付宝 
channelIds["000725"] = "t64"	--斯凯预装 
channelIds["000798"] = "t65"	--搜狗游戏中心 
channelIds["000799"] = "t66"	--搜狗移动搜索 
channelIds["000800"] = "t67"	--搜狗手机游戏中心 
channelIds["000801"] = "t68"	--17173安卓频道 
channelIds["000805"] = "t69"	--九城游戏中心 
channelIds["000857"] = "t6a"	--大可乐游戏大厅 
channelIds["000890"] = "t6b"	--卓易市场 
channelIds["000893"] = "t6c"	--聚乐子渠道 
channelIds["000894"] = "t6d"	--智享未来预装 
channelIds["000900"] = "t6e"	--唐腾 
channelIds["000914"] = "t6f"	--上海益玩 
channelIds["000915"] = "t70"	--友游 
channelIds["000916"] = "t71"	--偶玩 
channelIds["000924"] = "t72"	--丫丫玩 
channelIds["000930"] = "t73"	--网游开服助手 
channelIds["000931"] = "t74"	--37手游 
channelIds["000934"] = "t75"	--搜狗自有渠道 
channelIds["000936"] = "t76"	--享游(bilibili) 
channelIds["000955"] = "t77"	--37魅族 
channelIds["000958"] = "t78"	--芜湖享游 
channelIds["000961"] = "t79"	--土豆网 
channelIds["000994"] = "t7a"	--联想游戏中心 
channelIds["001011"] = "t7b"	--力天科技 
channelIds["001019"] = "t7c"	--青柠助手 
channelIds["001021"] = "t7d"	--品酷 
channelIds["001024"] = "t7e"	--YY语音 
channelIds["001025"] = "t7f"	--武汉晃游 
channelIds["001039"] = "t80"	--广点通 
channelIds["001049"] = "t81"	--17mobi 
channelIds["001050"] = "t82"	--蓝坤 
channelIds["001051"] = "t83"	--沃势 
channelIds["001069"] = "t84"	--博雅科诺 
channelIds["001082"] = "t85"	--靠谱助手 
channelIds["001083"] = "t86"	--巨人星云 
channelIds["001104"] = "t87"	--海马 
channelIds["001128"] = "t88"	--苏宁 
channelIds["001134"] = "t89"	--心动 
channelIds["001146"] = "t8a"	--南京-CocosPlay 
channelIds["001161"] = "t8b"	--新游 
channelIds["001165"] = "t8c"	--金山清理大师 
channelIds["001173"] = "t8d"	--应用管家 
channelIds["001176"] = "t8e"	--乐玩科技 
channelIds["001191"] = "t8f"	--5游 
channelIds["001201"] = "t90"	--叉叉助手 
channelIds["001208"] = "t91"	--斗鱼 
channelIds["001210"] = "t92"	--悠扬互动 
channelIds["110000"] = "t93"	--百度游戏 
channelIds["110001"] = "t94"	--蜗牛 
channelIds["110002"] = "t95"	--糖果游戏 
channelIds["110003"] = "t96"	--触控 
channelIds["110004"] = "t97"	--游龙移动 
channelIds["110005"] = "t98"	--35i手游 
channelIds["110006"] = "t99"	--掌娱天下 
channelIds["111222"] = "t9a"	--深蓝科创 
channelIds["111224"] = "t9b"	--中联支付 
channelIds["111243"] = "t9c"	--九玩游戏 
channelIds["111244"] = "t9d"	--49游 
channelIds["111247"] = "t9e"	--今日头条 
channelIds["160001"] = "t9f"	--TalkingData 
channelIds["160002"] = "ta0"	--爱贝 
channelIds["160006"] = "ta1"	--光涛互动 
channelIds["160007"] = "ta2"	--SohaGame 
channelIds["160010"] = "ta3"	--后鑫网络 
channelIds["001207"] = "ta4"	--重庆玖度 
channelIds["200001"] = "ta5"	--PADA游戏中心(艺果) 
channelIds["200028"] = "ta6"	--智乐(淘宝) 
channelIds["200034"] = "ta7"	--蜂助手 
channelIds["400038"] = "ta8"	--大圣投放SEM 
channelIds["400044"] = "ta9"	--投放-17173 
channelIds["400045"] = "taa"	--投放-百合网 
channelIds["400046"] = "tab"	--投放-风行 
channelIds["600001"] = "tac"	--GooglePlay 
channelIds["900051"] = "tad"	--有信 
channelIds["900097"] = "tae"	--酷划 
channelIds["001145"] = "taf"	--金立游戏中心（网游）
channelIds["111317"] = "tb0"	--搜狐游戏中心
channelIds["160068"] = "tb1"	--乾游游戏
channelIds["111226"] = "tb2"	--虫虫助手
channelIds["111303"] = "tb3"	--拇指游玩
channelIds["160029"] = "tb4"	--XY安卓手机助手
channelIds["111290"] = "tb5"	--武汉手盟
channelIds["000458"] = "tb6"	--美图秀秀
channelIds["111279"] = "tb7"	--Facebook
channelIds["000296"] = "tb8"	--乐视TV
channelIds["000065"] = "tb9"	--沃商店
channelIds["160033"] = "tba"	--小笨返利宝
channelIds["001205"] = "tbb"	--乐视手机
channelIds["000321"] = "tbc"	--电信爱游戏专版
channelIds["001141"] = "tbd"	--小米TV
channelIds["160044"] = "tbe"	--腾讯浏览器
channelIds["111323"] = "tbf"	--猎宝
channelIds["000255"] = "tc0"	--UC
channelIds["111262"] = "tc1"	--偶玩游戏


-- 分渠道  特殊处理
function AgentAdapter:SetChanneId(channeld)
	GLOBAL_CONFIG.package_info.config.agent_id = channelIds[channeld] or "aqy"
	print("channeld==", GLOBAL_CONFIG.package_info.config.agent_id)
end
