local agent_helper = require(AGENT_PATH .. "agent_helper")

AgentAdapter = {
	is_init = false,
	is_login_verify_ing = false,
	login_callback = nil,
	force_logout = false,
	login_verify_url = "http://cls.cp01.youyannet.com/hu8/login_verify.php",
	uid = "",
}

--退出
function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result) 
		if "true" == result then
			AdapterToLua:endGame()
		end
	end)
end

-- 初始化
function AgentAdapter:Init()

	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()
	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "hu8"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return self:GetSpid().."_".. self.uid
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[179]
end


-- 是否有管理中心
function AgentAdapter:IsHasManagerCenter()
	return false
end

--管理中心按钮监听
function AgentAdapter:OpenManagerCenter()
	if self:IsHasManagerCenter() then
		PlatformBinder:JsonCall("call_agent_open_mc", "", "")
	end
end




function AgentAdapter:Login(callback)
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))--设置登录回调 

end

function AgentAdapter:OnClickBackLogin()
	agent_helper:Logout()
end

function AgentAdapter:OnClickRestartGame()
	agent_helper:Logout()
end

function AgentAdapter:LoginCallback(result)--登录后回调

	local json_obj = cjson.decode(result)

    local real_url = string.format("%s?spid=%s&device=%s&uid=%s", self.login_verify_url, self:GetSpid(), tostring(PlatformAdapter.GetPhoneUniqueId()),json_obj.uid)

	local verify_callback = function(url, arg, data, size)
		
		self.is_login_verify_ing = false
		if size <= 0 then
			return
		end
		
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			return
		end
	
		self.uid = ret_t.user.uid
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())

		agent_helper:ShowFloatButton()
	end

	self.is_login_verify_ing = true
	
	Log("log_real_url====" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)

	return false
	
end

function AgentAdapter:LogoutCallback(result)--注销回调

	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)--购买
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end
    local orderId = server_id .. "_" .. self.uid .. "_" .. os.time()

	local param_obj = {}
	--Uid sdk用户的唯一id
    param_obj.Uid = self.uid
    --orderId 游戏订单 
    param_obj.orderId = orderId
    --amount支付金额（单位：分）
    param_obj.amount = amount * 100
    --productId商品id
    param_obj.productId = "1"
    --productDesc商品描述
    param_obj.productDesc = "元宝"
    --productName商品名称
    param_obj.productName = "元宝"
    --yuanbao商品单位（元宝，砖石）
    param_obj.yuanbao = "元宝"
    --roleId 角色id 
	param_obj.roleId = role_id
	--roleName 角色名字
	param_obj.roleName = role_name
	--serverId 服务器id 
	param_obj.serverId = server_id
	--content订单透传参数
	param_obj.content = orderId
	--gameName 游戏名称
	param_obj.gameName=self:GetGameName()

    local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()

	if role_vo ~= nil and user_vo ~= nil then
       --serverName服务器名字
		param_obj.serverName = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
		--level角色等级
        param_obj.level = tostring(role_vo.level) or "0"
	    --balance余额
	    param_obj.balance = RoleData.Instance.role_info.gold or "0" --角色元宝余额
	    --vip vip等级
	    param_obj.vip = tostring(role_vo.vip_level) or "0" --vip
	    --partyName工会
	     param_obj.partyName = RoleData.Instance.role_vo.guild_name or "无" --帮派
	else
       --serverName服务器名字
		param_obj.serverName = "_"
		--level角色等级
		param_obj.level = "0"
	    --balance余额
		param_obj.balance = "0" 
		 --vip vip等级
	    param_obj.vip = "0"
	      --partyName工会
	    param_obj.partyName = "0" --帮派
	end

	-- Log("AgentAdapter:Pay======" .. tostring(cjson.encode(param_obj))

	agent_helper:Pay(tostring(cjson.encode(param_obj)), nil)
end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self:SubmitInfo(0)
end

-- 角色信息返回后上报
function AgentAdapter:SubmitRoleInfoAck()
	self:SubmitInfo(1)--进入游戏上报(sdk版本3.14.2新加的setData接口)
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(2)
end


function AgentAdapter:SubmitInfo(type)
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()

	if role_vo ~= nil and user_vo ~= nil then
		local info={}
	    --Uid sdk的用户唯一标识
		info.uid = self.uid
		--serviceid游戏服务器id
		info.serviceid = role_vo.server_id
		--serviceName游戏服务器名称
		info.serviceName = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name --服务器id + 服务器名字
		--roleId游戏角色id
		info.roleId = role_vo.role_id
		--roleName游戏角色名字
		info.roleName = role_vo.role_name
		--grade游戏角色等级
		info.grade = tostring(role_vo.level) or "0"
		--partyName角色所属工会名字
		info.partyName = RoleData.Instance.role_vo.guild_name or "无" 
		--roleCTime角色创建时间
		if type == 0 then
			info.roleCTime =os.time()
		else
			info.roleCTime = tostring(role_vo.role_create_time) or "0"
		end

		info.roleLevelMTime = os.time()
	

		Log("AgentAdapter:SubmitInfo======" .. cjson.encode(info))
		agent_helper:SubmitExtendData(cjson.encode(info))
	end
end


--是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end
