local agent_helper = require(AGENT_PATH .. "agent_helper")

AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	is_login_verify_ing = false,
	login_verify_url = "cls.cp01.youyannet.com/hv9/login_verify.php",
	pay_callback_url = "http://cls.cp01.youyannet.com/hv9/pay_callback.php",
	uid = "",
}

function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result)
		if result == "true" then
			AdapterToLua:endGame()
		else
			local format = { title = "退出", message = "退出游戏?", positive = "确定", negative = "取消", }
			PlatformAdapter:OpenAlertDialog(format, 
			function (result) 
				if "positive" == result then 
					PlatformBinder:JsonCall("call_agent_exit", "true", "", function(result) AdapterToLua:endGame() end)
				end 
			end)
		end			
	end)
end

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end

	local cache_data = Split((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), "_")
	if cache_data ~= nil then
		GLOBAL_CONFIG.package_info.config.agent_id = cache_data[1] or "hv9"
		self.uid = cache_data[2] or ""
	end

	print("===========", self.uid)

	self.is_init = true
	AgentMs:InitLocalPush()

	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "hv9"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return self:GetSpid() .. "_" .. self.uid
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[177]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "big_logo_tyxy2"
end

--获得loadingbgname
function AgentAdapter:GetLoadingbgName()
	return "loading_bg_empty"
end

-- 是否有管理中心
function AgentAdapter:IsHasManagerCenter()
	return true
end

-- 打开管理中心
function AgentAdapter:OpenManagerCenter()
	if self:IsHasManagerCenter() then
		PlatformBinder:JsonCall("call_agent_manager_center", "", "", function(arg)
			SysMsgCtrl.Instance:ErrorRemind("暂不支持该功能", true)
		end)
	end
end

function AgentAdapter:LoginCallback(result)
	local json_obj = cjson.decode(result)

	local verify_callback = function(url, arg, data, size)
		self.is_login_verify_ing = false
		if size <= 0 then
			Log("verify_callback, fail:size<=0")
			return
		end
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			Log("verify_callback, fail")
			return
		end
		self.uid = ret_t.user.uid
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())
	end

	self.is_login_verify_ing = true
	local device = tostring(PlatformAdapter.GetPhoneUniqueId())
	local real_url = string.format("%s?spid=%s&uid=%s&token=%s&device=%s", self.login_verify_url, self:GetSpid(), json_obj.userid, json_obj.token, device)
	Log("start verify login: url=" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:LogoutCallback(result)
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter:Logout()
	agent_helper:Logout()
end

function AgentAdapter:OnClickBackLogin()
	agent_helper:Logout()
end

function AgentAdapter:OnClickRestartGame()
	agent_helper:Logout()
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)

	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()
	if role_vo ~= nil and user_vo ~= nil then
		local info = {}

		if RoleData.Instance and RoleData.Instance.role_info then
			info.CoinNum = RoleData.Instance.role_info.gold or "0"
		else
			info.CoinNum = "0"
		end

		info.BuyNum = "1"
		info.Extension = server_id .. "_" .. self:GetOpenId() .. "_" .. os.time() .. "_" .. self:GetSpid()
		info.Price = amount
		info.ProductId = "0"
		info.ProductName = amount * 10 .. "元宝"
		info.ProductDesc = "充值" .. amount * 10 .. "元宝"
		info.RoleId = role_id
		info.RoleLevel = tostring(role_vo.level) or "0"
		info.RoleName = role_name
		info.ServerId = server_id
		info.ServerName = user_vo.plat_server_name
		info.Vip = RoleData.Instance.role_vo.vip_level or 0

		print(cjson.encode(info))
		agent_helper:Pay(cjson.encode(info))
	end
	
end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self:SubmitInfo(0)
end

-- 进入游戏上报
function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(1)
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(2)
end


function AgentAdapter:SubmitInfo(type)
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()

	if role_vo ~= nil and user_vo ~= nil then
		local info = {}
		info.server_id = tostring(user_vo.plat_server_id)
		info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
		info.role_name = role_vo.name
		info.role_id = tostring(role_vo.role_id)
		info.user_level = tostring(role_vo.level) or "0"
		info.vip_level = tostring(role_vo.vip_level) or "0"

		if RoleData.Instance and RoleData.Instance.role_info then
			info.gold = RoleData.Instance.role_info.gold or "0"
			info.party_name = RoleData.Instance.role_vo.guild_name or ""
		else
			info.gold = "0"
			info.party_name = ""
		end
		info.sub_type = type

		print(cjson.encode(info))
		agent_helper:SubmitExtendData(cjson.encode(info))
	end
end


-- 是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end