local agent_helper = require(AGENT_PATH .. "agent_helper")

function PlatformAdapter:GetShareDataFromFile()
	local local_cfg = cjson.decode(UtilEx:readText(UtilEx:getDataPath() .. "sharedata.txt")) or {}
	return local_cfg
end

function PlatformAdapter:SaveShareDataToFile(data)
	if nil == data then return end
	local cfg_text = cjson.encode(data)
	if nil ~= cfg_text then
		UtilEx:writeText(UtilEx:getDataPath() .. "sharedata.txt", cfg_text)
	end
end

function PlatformAdapter:GetShareValueByKey(key)
	return GLOBAL_CONFIG.share_data[key]
end

function PlatformAdapter:SaveShareValue(key, value)
	GLOBAL_CONFIG.share_data[key] = value
	self:SaveShareDataToFile(GLOBAL_CONFIG.share_data)
end

GLOBAL_CONFIG.share_data = PlatformAdapter:GetShareDataFromFile()

AgentAdapter = {
	is_init = false,
	agent_name = "ye4",

	login_callback = nil,
	login_fail_callback = nil,
	auto_login_flag = false,
	session_id = "",
	pay_success_callback = nil,

	inquery_money_url = "cls.cp01.youyannet.com/ye4/pay_callback.php",
	inquery_money_time_out = 10,				--查询余额超时时间
	inquery_money_frequency = 15,				--查询余额频率
	inquery_money_back_fail_max_times = 4,		--查询返回失败后查询余额最大次数,上线查的次数和刚充完查的次数不同	
	inquery_money_back_fail_times = 0,
	inquery_money_delay_timer = nil,
	is_pay_inquery_ing = false,

	open_id = "",
	mid = "",

	pay_type_url = "cls.cp01.youyannet.com/ye4/pay_type.php",
	web_recharge_rul = "http://uspay.sdk.ffcai.com:8911/Pay/defaul.aspx", -- 921网页支付
	web_recharge_key = "adw20xdd",										  -- 固定值
	web_product_num = "P0000142",										  -- 产品编号
	web_channel_id = "SCQ0001698",										  -- 渠道ID

	gdt_url = "http://txad.921.com/api/adregister.ashx",				  -- 广点通上报地址
}

AgentAdapter.Platform = {
	ePlatform_Weixin = 1,		--微信平台
	ePlatform_QQ = 2,			--手Q平台
}

AgentAdapter.TokenType = {
    eToken_QQ_Access = 1,    	--手Q accesstoken  查询手Q个人、好友、关系链、分享等功能
    eToken_QQ_Pay = 2,          --手Q paytoken  支付相关
    eToken_WX_Access = 3,       --微信 accesstoken 查询微信个人、好友、关系链、分享、支付等
    eToken_WX_Code = 4,         --游戏不需要关心
    eToken_WX_Refresh = 5,      --微信refreshtoken 刷新accesstoken
}

-- 平台ID
function AgentAdapter:GetSpid()
	return "ye4"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.open_id
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return self:GetSpid() .. "_" .. self.open_id
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[57]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "big_logo_dxz"
end

--获得loadingbgname
function AgentAdapter:GetLoadingbgName()
	return "loading_bg_empty"
end

function AgentAdapter:Init()
	if self.is_init then return end
	self.is_init = true
	self.open_id = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	AgentMs:InitLocalPush()
	
	PlatformBinder:JsonBind("event_agent_show_msg", function(result)
		SysMsgCtrl.Instance:ErrorRemind(result, true)
		return true
	end)

	-- 广点通上报
	PlatformBinder:JsonBind("request_mid_callback", function(result)
		print("广点通上报=======" .. result)
		self.mid = result
		local user_vo = GameVoManager.Instance:GetUserVo()
		if self.open_id ~= "" and self.mid ~= "" and user_vo.server_id ~= "" then

			local regtime = os.date("%Y-%m-%d %X", os.time())
			local mac = ""
			local imei = self.mid
			local ip = PlatformAdapter.GetIpAddress()
			local sign = UtilEx:md5Data(self.web_product_num .. self.open_id)
			local idfa = ""
			local app_type = "android"

			local url = string.format("%s?pid=%s&gcid=%s&regtime=%s&uid=%s&mac=%s&imei=%s&ip=%s&idfa=%s&app_type=%s&sign=%s", 
				self.gdt_url, self.web_product_num, self.web_channel_id, regtime, self.open_id, mac, imei, ip, idfa, app_type, sign)

			print(url)
			HttpClient:Request(url, "")
		end
		return true
	end)

end

--点击返回登录认为是注销
function AgentAdapter:OnClickBackLogin()
	AgentAdapter:Logout()
end

--当首次进入游戏场景时（即玩家第一次看到游戏地图时）
function AgentAdapter:OnFirstEnterGameScene()
	AgentAdapter:InqueryMoney()
	PlatformBinder:JsonCall("call_agent_request_mid") -----------出包后再打开
end

-----------------------------------------
--登录相关
-----------------------------------------
function AgentAdapter:Login_InQQ(callback, login_fail_callback)
	self:Login(callback, login_fail_callback, AgentAdapter.Platform.ePlatform_QQ)
end

function AgentAdapter:Login_InWX(callback, login_fail_callback)
	self:Login(callback, login_fail_callback, AgentAdapter.Platform.ePlatform_Weixin)
end

function AgentAdapter:SwitchAccount(callback)
	self.login_callback = callback
	agent_helper:Logout()
end

function AgentAdapter:AutoLogin(callback, login_fail_callback)
	self.login_callback = callback
	self.login_fail_callback = login_fail_callback

	local arg_t = {is_auto_login = "true"}
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback), cjson.encode(arg_t))
end

function AgentAdapter:Login(callback, login_fail_callback, platform)
	self.login_callback = callback
	self.login_fail_callback = login_fail_callback

	local arg_t = {is_auto_login = "false", platform = platform}

	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback), cjson.encode(arg_t))
end

function AgentAdapter:LoginCallback(result)
	print("AgentAdapter:LoginCallback" .. result)

	self.open_id = agent_helper:GetSessionId()
	if "true" == result and self.open_id ~= "" and self.open_id ~= nil then
		self.login_callback(self:GetPlatName())
		return true
	else

		SysMsgCtrl.Instance:ErrorRemind("登录失败,请再次尝试", true)
		if nil ~= self.login_fail_callback then
			self.login_fail_callback()
		end
		
	end

	return false
end

function AgentAdapter:Logout()
	agent_helper:Logout()
end

function AgentAdapter:LogoutCallback(result)
	print("AgentAdapter:LogoutCallback " .. result)
	-- if "true" == result then
	-- 	AdapterToLua:getInstance():setDataCache("RELOGIN_FLAG", "true")
	-- 	AdapterToLua:restart()
	-- end
	return true
end

-----------------------------------------
--充值相关
-----------------------------------------
function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	if AgentAdapter.is_pay_inquery_ing then
		SysMsgCtrl.Instance:ErrorRemind("上一次充值还未到帐，请稍候")
		return
	end
	local verify_callback = function(url, arg, data, size)	
		local ret_t = cjson.decode(data)
		if ret_t ~= nil and ret_t.pay_type == "1" then
			if GLOBAL_CONFIG.package_info.version < 17000000 then
				-- 921网页支付
			    self:WebRecharge(role_id, role_name, amount, server_id)
			else
				--深海支付
				self:ShenhaiRecharge(role_id, role_name, amount, server_id)
	        end 
		else
			-- 腾讯支付
			AgentAdapter.pay_success_callback = callback
			local user_vo = GameVoManager.Instance:GetUserVo()
			print("AgentAdapter.pay:", user_vo.real_server_id)
			AgentAdapter:Recharge(amount, "false", user_vo.real_server_id)
		end
	end

	HttpClient:Request(self.pay_type_url, "", verify_callback)
end

--深海支付
function AgentAdapter:ShenhaiRecharge(role_id, role_name, amount, server_id)

	local user_vo = GameVoManager.Instance:GetUserVo()
	local order_id = server_id .. "_" .. self:GetPlatName() .. "_" .. os.time()
	
	local info = {}
	info.DisId = server_id
	info.DisName = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
	info.Number = amount * 10
	info.RoleId = role_id
	info.RoleName = role_name
	info.Uid = self.open_id
	info.GameNo = order_id
	info.role_level = tostring(GameVoManager.Instance:GetMainRoleVo().level) or "0"

	info.Amount = amount * 100
	info.order_desc = "元宝"
	info.order_name = amount * 10 .. "元宝"
	info.product_name = "元宝"
	info.productId = ""

	print(cjson.encode(info))
	PlatformBinder:JsonCall("call_agent_shenhai_pay", cjson.encode(info))

end



-- 网页充值
function AgentAdapter:WebRecharge(role_id, role_name, amount, server_id)
	local time = os.date("%Y-%m-%d %X", os.time())
	local order_id = server_id .. "_" .. self:GetPlatName() .. "_" .. os.time()
	local random = ""
	for i = 1, 5 do 
		random = random .. tostring(math.random(0, 9))
	end	

	local user_vo = GameVoManager.Instance:GetUserVo()
	local server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name

	local params = string.format("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s", random..self.open_id, time, self.web_product_num, self.web_channel_id, server_id,
		server_name, role_id, role_name, amount*10, order_id)
	local p = UtilEx:md5Data("MD5" .. self.open_id .. time .. self.web_recharge_key)
	local s = mime.b64(HttpClient:UrlEncode(params))

	local url = string.format("%s?p=%s&s=%s", self.web_recharge_rul, p, s)
	print("WebRecharge==", url)
	-- PlatformAdapter.OpenWebView(url)
	PlatformAdapter:OpenBrowser(url)
end


--充值。。
function AgentAdapter:Recharge(default_value, is_can_change, server_id)
	default_value = default_value or "0"
	default_value = default_value * 10   --转成元宝 
	is_can_change = is_can_change or "false"
	Log("AgentAdapter:Recharge" .. default_value, server_id)
	local recharge_info_t = {default_value = default_value, is_can_change = is_can_change, server_id = "1"} -- 写死1了，，不区分
	local recharge_info = cjson.encode(recharge_info_t)
	agent_helper:Recharge(recharge_info)
end

function AgentAdapter:RechargeCallback(data)
	data = data or ""
	Log("AgentAdapter:RechargeCallback" .. data)
	local result = cjson.decode(data)
	if nil == result or nil == result.resultCode or nil == result.payState then
		return true
	end 

	if -1 == result.resultCode then
		SysMsgCtrl.Instance:ErrorRemind("支付流程失败")
	end
	if 2 == result.resultCode then
		SysMsgCtrl.Instance:ErrorRemind("用户取消")
	end

	if 0 == result.resultCode then
		SysMsgCtrl.Instance:ErrorRemind("支付流程成功")
		if 1 == result.payState	then
			SysMsgCtrl.Instance:ErrorRemind("用户取消")
		end
		if 2 == result.payState	then
			SysMsgCtrl.Instance:ErrorRemind("支付出错")
		end
		if 0 == result.payState	then
			SysMsgCtrl.Instance:ErrorRemind("支付成功")
			AgentAdapter.inquery_money_back_fail_max_times = 150
			AgentAdapter.is_pay_inquery_ing = true 
			--查询数额
			AgentAdapter:InqueryMoney()

			if AgentAdapter.pay_success_callback then
				AgentAdapter.pay_success_callback()
			end
		end
	end
	return true
end

--查询余额
function AgentAdapter:InqueryMoney()
	AgentAdapter.inquery_money_back_fail_times = 0

	if AgentAdapter.inquery_money_delay_timer then
		GlobalTimerQuest:CancelQuest(AgentAdapter.inquery_money_delay_timer)
		AgentAdapter.inquery_money_delay_timer = nil
	end

	self:DoInqueryMoney()	
end

function AgentAdapter:DoInqueryMoney()
	local pay_info_str = agent_helper:GetPayInfo()
	local pay_info = cjson.decode(pay_info_str) or {}
	--local server_id = GameVoManager.Instance:GetUserVo().plat_server_id
	local server_id = GameVoManager.Instance:GetUserVo().real_server_id


	local gdt = {}

	local user_vo = GameVoManager.Instance:GetUserVo()
	local role_vo = GameVoManager.Instance:GetMainRoleVo()

	if user_vo ~= nil and role_vo ~= nil then
		gdt.time = os.date("%Y-%m-%d %X", os.time())
		gdt.rolename = role_vo.name
		gdt.disname = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
		gdt.imei = self.mid
	end

	local url = AgentAdapter.inquery_money_url .. "?openid=%s&openkey=%s&pay_token=%s&pf=%s&pfkey=%s&server_id=%d&session_id=%s&session_type=%s&gdt=%s"
	url = string.format(url, pay_info.openid, pay_info.openkey, pay_info.pay_token, pay_info.pf, pay_info.pfkey, server_id, pay_info.session_id, pay_info.session_type, cjson.encode(gdt))
	Log("AgentAdapter：DoInqueryMoney," .. url)

	local inquery_callback = function(url, arg, data, size)
		if AgentAdapter.inquery_money_delay_timer then 
			GlobalTimerQuest:CancelQuest(AgentAdapter.inquery_money_delay_timer)
			AgentAdapter.inquery_money_delay_timer = nil
		end
		local result = cjson.decode(data)
		Log("AgentAdapter：InqueryMoneyCallback,data=" .. data) 
		local is_need_inquery_again = false
		if result == nil or result.ret == nil or result.msg == nil then
			is_need_inquery_again = true
		else
			if result.ret ~= 0 then
				if AgentAdapter.inquery_money_back_fail_times < AgentAdapter.inquery_money_back_fail_max_times then
					is_need_inquery_again = true
					AgentAdapter.inquery_money_back_fail_times = AgentAdapter.inquery_money_back_fail_times + 1
				end
			else
				AgentAdapter.is_pay_inquery_ing = false
				local uoid = result.billno or ""
				local money = result.money or 0
				AgentMs:StatisticsPay(uoid, money, 0)
			end	
		end
		
		if is_need_inquery_again then
			AgentAdapter.inquery_money_delay_timer = GlobalTimerQuest:AddDelayTimer(LUA_CALLBACK(AgentAdapter, AgentAdapter.DoInqueryMoney), AgentAdapter.inquery_money_frequency)
		end
	end

	HttpClient:Request(url, "", inquery_callback)
	AgentAdapter.inquery_money_delay_timer = GlobalTimerQuest:AddDelayTimer(LUA_CALLBACK(AgentAdapter, AgentAdapter.DoInqueryMoney), AgentAdapter.inquery_money_time_out)
end

-- 是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end


agent_helper:SetLogoutCallback(LUA_CALLBACK(AgentAdapter, AgentAdapter.LogoutCallback))
agent_helper:SetRechargeCallback(LUA_CALLBACK(AgentAdapter, AgentAdapter.RechargeCallback))

